==> kubernetes-model-batch-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/batch/v1beta1/CronJobFluentImpl.java <==
package io.fabric8.kubernetes.api.model.batch.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CronJobFluentImpl<A extends CronJobFluent<A>> extends BaseFluent<A> implements CronJobFluent<A>{
  public CronJobFluentImpl() {
  }
  public CronJobFluentImpl(CronJob instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private CronJobSpecBuilder spec;
  private CronJobStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public CronJobFluent.MetadataNested<A> withNewMetadata() {
    return new CronJobFluentImpl.MetadataNestedImpl();
  }
  public CronJobFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new CronJobFluentImpl.MetadataNestedImpl(item);
  }
  public CronJobFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public CronJobFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public CronJobFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public CronJobSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public CronJobSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(CronJobSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new CronJobSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public CronJobFluent.SpecNested<A> withNewSpec() {
    return new CronJobFluentImpl.SpecNestedImpl();
  }
  public CronJobFluent.SpecNested<A> withNewSpecLike(CronJobSpec item) {
    return new CronJobFluentImpl.SpecNestedImpl(item);
  }
  public CronJobFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public CronJobFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new CronJobSpecBuilder().build());
  }
  public CronJobFluent.SpecNested<A> editOrNewSpecLike(CronJobSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public CronJobStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public CronJobStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(CronJobStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new CronJobStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public CronJobFluent.StatusNested<A> withNewStatus() {
    return new CronJobFluentImpl.StatusNestedImpl();
  }
  public CronJobFluent.StatusNested<A> withNewStatusLike(CronJobStatus item) {
    return new CronJobFluentImpl.StatusNestedImpl(item);
  }
  public CronJobFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public CronJobFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new CronJobStatusBuilder().build());
  }
  public CronJobFluent.StatusNested<A> editOrNewStatusLike(CronJobStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CronJobFluentImpl that = (CronJobFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<CronJobFluent.MetadataNested<N>> implements CronJobFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) CronJobFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends CronJobSpecFluentImpl<CronJobFluent.SpecNested<N>> implements CronJobFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(CronJobSpec item) {
      this.builder = new CronJobSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new CronJobSpecBuilder(this);
    }
    CronJobSpecBuilder builder;
    public N and() {
      return (N) CronJobFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends CronJobStatusFluentImpl<CronJobFluent.StatusNested<N>> implements CronJobFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(CronJobStatus item) {
      this.builder = new CronJobStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new CronJobStatusBuilder(this);
    }
    CronJobStatusBuilder builder;
    public N and() {
      return (N) CronJobFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-batch-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/batch/v1beta1/CronJobFluentImpl.java <==
package io.fabric8.kubernetes.api.model.batch.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CronJobFluentImpl<A extends CronJobFluent<A>> extends BaseFluent<A> implements CronJobFluent<A>{
  public CronJobFluentImpl() {
  }
  public CronJobFluentImpl(CronJob instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private CronJobSpecBuilder spec;
  private CronJobStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public CronJobFluentImpl.MetadataNested<A> withNewMetadata() {
    return new CronJobFluentImpl.MetadataNestedImpl();
  }
  public CronJobFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new CronJobFluentImpl.MetadataNestedImpl(item);
  }
  public CronJobFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public CronJobFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public CronJobFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public CronJobSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public CronJobSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(CronJobSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new CronJobSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public CronJobFluentImpl.SpecNested<A> withNewSpec() {
    return new CronJobFluentImpl.SpecNestedImpl();
  }
  public CronJobFluentImpl.SpecNested<A> withNewSpecLike(CronJobSpec item) {
    return new CronJobFluentImpl.SpecNestedImpl(item);
  }
  public CronJobFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public CronJobFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new CronJobSpecBuilder().build());
  }
  public CronJobFluentImpl.SpecNested<A> editOrNewSpecLike(CronJobSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public CronJobStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public CronJobStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(CronJobStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new CronJobStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public CronJobFluentImpl.StatusNested<A> withNewStatus() {
    return new CronJobFluentImpl.StatusNestedImpl();
  }
  public CronJobFluentImpl.StatusNested<A> withNewStatusLike(CronJobStatus item) {
    return new CronJobFluentImpl.StatusNestedImpl(item);
  }
  public CronJobFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public CronJobFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new CronJobStatusBuilder().build());
  }
  public CronJobFluentImpl.StatusNested<A> editOrNewStatusLike(CronJobStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CronJobFluentImpl that = (CronJobFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<CronJobFluentImpl.MetadataNested<N>> implements CronJobFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) CronJobFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends CronJobSpecFluentImpl<CronJobFluentImpl.SpecNested<N>> implements CronJobFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(CronJobSpec item) {
      this.builder = new CronJobSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new CronJobSpecBuilder(this);
    }
    CronJobSpecBuilder builder;
    public N and() {
      return (N) CronJobFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends CronJobStatusFluentImpl<CronJobFluentImpl.StatusNested<N>> implements CronJobFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(CronJobStatus item) {
      this.builder = new CronJobStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new CronJobStatusBuilder(this);
    }
    CronJobStatusBuilder builder;
    public N and() {
      return (N) CronJobFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
